==> woost-1.1.1.tar.gz: woost-1.1.1/woost/extensions/shorturls/strings.py <==
#-*- coding: utf-8 -*-
u"""

.. moduleauthor:: Martí Congost <marti.congost@whads.com>
"""
from cocktail.translations import translations

# Site
#------------------------------------------------------------------------------
translations.define("Site.url_shortener",
    ca = u"Servei d'URLs curtes",
    es = u"Servicio de URLs cortas",
    en = u"Short URLs service"
)

# URLShortener
#------------------------------------------------------------------------------
translations.define("URLShortener",
    ca = u"Servei d'escurçat d'URLs",
    es = u"Servicio de compactación de URLs",
    en = u"URL shortening service"
)

translations.define("URLShortener-plural",
    ca = u"Serveis d'escurçat d'URLs",
    es = u"Servicios de compactación de URLs",
    en = u"URL shortening services"
)

translations.define("URLShortener.title",
    ca = u"Nom",
    es = u"Nombre",
    en = u"Name"
)

# BitlyURLShortener
#------------------------------------------------------------------------------
translations.define("BitlyURLShortener",
    ca = u"Compte de bit.ly",
    es = u"Cuenta de bit.ly",
    en = u"bit.ly account"
)

translations.define("BitlyURLShortener-plural",
    ca = u"Comptes de bit.ly",
    es = u"Cuentas de bit.ly",
    en = u"bit.ly accounts"
)

translations.define("BitlyURLShortener.login",
    ca = u"Identificador del compte",
    es = u"Identificador de la cuenta",
    en = u"Login"
)

translations.define("BitlyURLShortener.api_key",
    ca = u"Clau de l'API",
    es = u"Clave de la API",
    en = u"API account"
)

==> woost-2.2.2.tar.gz: woost-2.2.2/woost/extensions/shorturls/strings.py <==
#-*- coding: utf-8 -*-
u"""

.. moduleauthor:: Martí Congost <marti.congost@whads.com>
"""
from cocktail.translations import translations

# Configuration
#------------------------------------------------------------------------------
translations.define("Configuration.services.short_urls",
    ca = u"Escurçat d'URLs",
    es = u"URLs cortas",
    en = u"Short URLs"
)

translations.define("Configuration.url_shortener",
    ca = u"Servei d'URLs curtes",
    es = u"Servicio de URLs cortas",
    en = u"Short URLs service"
)

# URLShortener
#------------------------------------------------------------------------------
translations.define("URLShortener",
    ca = u"Servei d'escurçat d'URLs",
    es = u"Servicio de compactación de URLs",
    en = u"URL shortening service"
)

translations.define("URLShortener-plural",
    ca = u"Serveis d'escurçat d'URLs",
    es = u"Servicios de compactación de URLs",
    en = u"URL shortening services"
)

translations.define("URLShortener.title",
    ca = u"Nom",
    es = u"Nombre",
    en = u"Name"
)

# BitlyURLShortener
#------------------------------------------------------------------------------
translations.define("BitlyURLShortener",
    ca = u"Compte de bit.ly",
    es = u"Cuenta de bit.ly",
    en = u"bit.ly account"
)

translations.define("BitlyURLShortener-plural",
    ca = u"Comptes de bit.ly",
    es = u"Cuentas de bit.ly",
    en = u"bit.ly accounts"
)

translations.define("BitlyURLShortener.login",
    ca = u"Identificador del compte",
    es = u"Identificador de la cuenta",
    en = u"Login"
)

translations.define("BitlyURLShortener.api_key",
    ca = u"Clau de l'API",
    es = u"Clave de la API",
    en = u"API account"
)
